const pharmacyRouter = require("./routes/pharmacy");
const requestRouter = require("./routes/request");
const dotenv = require("dotenv");
const morgan = require("morgan");
const { handleWhatsappReplies } = require("./services/twilio");
// this line is to read the environment variables from the config.env file
dotenv.config({ path: "config.env" });
const dbConnection = require("./config/database");

const express = require("express");
const app = express();
//middleware
// Middleware for parsing URL-encoded bodies
app.use(express.urlencoded({ extended: true }));
app.use(
  express.json({
    verify: (req, res, buf) => {
      if (buf && buf.length > 0) {
        req.rawBody = buf.toString();
      } else {
        req.rawBody = ""; // Set a default value if buf doesn't exist
      }
    },
  })
);

//CONNECT TO DATABASE
dbConnection();
//logging
if (process.env.NODE_ENV === "development") {
  app.use(morgan("dev"));
}
//home route
app.get("/", (req, res) => {
  res.send("Welcome to Pharmacy API");
});
//mount routes
app.use("/api/v1/pharmacies", pharmacyRouter);
app.use("/api/v1/requests", requestRouter);
//---------------------------
//twiiio webhook
app.post("/reply", async (req, res) => {
  await handleWhatsappReplies(req.body);
});

//running server
app.listen(process.env.PORT || 8000, () => {
  console.log(`Server is running on port ${process.env.PORT}`);
});
