const Pharmacy = require("../models/pharmacy");

//-----------------------------------------------
exports.filterObj = (req, res, next) => {
  const { location } = req.query;
  if (location) {
    const [longitude, latitude] = location.split(",");
    if (longitude && latitude) {
      req.filterObj = { location: [+longitude, +latitude] };
    }
  }
  next();
};
//-----------------------------------------------
exports.createOne = async (req, res) => {
  try {
    req.body.location = {
      type: "Point",
      coordinates: req.body.location,
    };

    const pharmacy = await Pharmacy.create(req.body);
    if (!pharmacy) {
      return res
        .status(404)
        .json({ status: "failed", message: "Pharmacy not created" });
    }
    return res.status(200).json({
      status: "success",
      message: "Pharmacy created successfully",
      data: pharmacy,
    });
  } catch (error) {
    return res.status(400).json({ status: "error", message: error.message });
  }
};
//-----------------------------------------------
exports.getAll = async (req, res) => {
  try {
    let filter = {};
    if (req.filterObj?.location) {
      filter = {
        location: {
          $near: {
            $geometry: {
              type: "Point",
              coordinates: req.filterObj.location, //that comming from user
            },
            $maxDistance: req.query.radius || 100_000, //distance in meters
          },
        },
      };
    }

    const pharmacies = await Pharmacy.find(filter);
    //check if there are no pharmacies
    if (pharmacies.length === 0) {
      return res
        .status(404)
        .json({ status: "failed", message: "No pharmacies found" });
    }
    //return response
    return res.status(200).json({ status: "success", data: pharmacies });
  } catch (error) {
    return res.status(404).json({ status: "error", error: error.message });
  }
};
//-----------------------------------------------
exports.getOne = async (req, res) => {
  try {
    const pharmacy = await Pharmacy.findById(req.params.id);
    if (!pharmacy) {
      return res
        .status(404)
        .json({ status: "failed", message: " pharmacy not found" });
    }
    return res.status(200).json({ status: "success", data: pharmacy });
  } catch (error) {
    return res.status(400).json({ status: "error", error: error.message });
  }
};
//-----------------------------------------------
exports.updateOne = async (req, res) => {
  try {
    const pharmacy = await Pharmacy.findByIdAndUpdate(req.params.id, req.body, {
      new: true,
    });
    if (!pharmacy) {
      return res
        .status(404)
        .json({ status: "failed", message: " pharmacy not found" });
    }
    res.status(200).json({ status: `updated successfully`, pharmacy });
  } catch (error) {
    res.status(400).send(error);
  }
};
//-----------------------------------------------
exports.deleteOne = async (req, res) => {
  try {
    const pharmacy = await Pharmacy.findByIdAndDelete(req.params.id);
    if (!pharmacy) {
      return res
        .status(404)
        .json({ status: "failed", message: " pharmacy not found" });
    }
    res.send(pharmacy);
  } catch (error) {
    res.status(400).send(error);
  }
};
//---------------------------
exports.getPharmacies = async (pharmaciesIds) => {
  const pharmacies = await Pharmacy.find({ _id: { $in: pharmaciesIds } });
  return pharmacies;
};
