const Request = require("../models/request");
const relatedMessageService = require("./relatedMessage");
const { getPharmacies } = require("./pharmacy");
const { sendMessage } = require("./twilio");
//guestId

exports.createOne = async (req, res) => {
  try {
    //1 - get pharmacies from the given pharmaciesIds
    const pharmacies = await getPharmacies(req.body.pharmaciesIds);
    if (pharmacies.length === 0) {
      return res.status(404).json({
        status: "failed",
        message: "No pharmacies found from the given pharmaciesIds",
      });
    }
    //2- create request doc with the given data
    const request = await Request.create(req.body);
    if (!request) {
      return res.status(400).json({
        status: "failed",
        message: "error in creating Request ",
      });
    }
    //2 - create related_messages doc that contains the requestId and the pharmaciesIds(which have the medicine)
    const relatedMessagesId = await relatedMessageService.createOne({
      requestId: request._id,
      pharmacies: [],
    });
    //send message to pharmacies through whatsapp via twilio
    //for testing purpose
    await sendMessage({
      message: `hello\nid : ${relatedMessagesId}\ndo you have '${req.body.medicine}' medicine \nreply with id-value+-+answer\n${relatedMessagesId}-yes \nor\n${relatedMessagesId}-no`,
      to: req.body.to || "+201154765066",
    });
    //real scenario
    // pharmacies.map(async (pharmacy) => {
    //   sendMessage({
    //     message: `hello ${pharmacy.name}\nrequestId : ${request._id}\ndo you have '${req.body.medicine}' medicine \n reply with requestId+space+answer\nrequestId yes or requestId no`,
    //     to: pharmacy.phone,
    //     pharmacyId: pharmacy._id,
    //   });
    // });
    return res.status(200).json({
      status: "success",
      message: "Request created successfully",
      request,
    });
  } catch (error) {
    return res.status(400).json({ status: "error", message: error.message });
  }
};

exports.getRequestReplies = async (req, res) => {
  try {
    const requestRelatedMessages =
      await relatedMessageService.getRelatedMessages(
        req.params.id //requestId
      );
    if (requestRelatedMessages.pharmacies.length === 0) {
      return res.status(404).json({
        status: "failed",
        message: "No replies found yet",
      });
    }
    return res.status(200).json({
      status: "success",
      replies: requestRelatedMessages.pharmacies,
    });
  } catch (error) {
    return res.status(400).json({ status: "error", message: error.message });
  }
};

exports.deleteOne = async (req, res) => {
  try {
    const request = await Request.findByIdAndDelete(req.params.id);
    if (!request) {
      return res.status(404).json({
        status: "failed",
        message: "Request not found",
      });
    }
    await relatedMessageService.deleteRelatedMessage(req.params.id);
    return res.status(200).json({
      status: "success",
      message: "Request deleted successfully",
    });
  } catch (error) {
    return res.status(400).json({ status: "error", message: error.message });
  }
};
// exports.getOne = async (req, res) => {
